diff -r 33deaa931635 misc.c
--- a/misc.c    Thu Sep 30 14:30:34 2010 +0100
+++ b/misc.c    Thu Jul 21 22:11:52 2011 +0300
@@ -1279,9 +1279,9 @@
   if (IN_CLASSD(ntohl(ipaddr.sin_addr.s_addr)))
   {
     // Needed if we're doing multicast
-    byte ttl = 16;
+    int ttl = 16;
     result = setsockopt(output, IPPROTO_IP, IP_MULTICAST_TTL,
-                        (char *)&ttl, sizeof(ttl));
+                        &ttl, sizeof(ttl));
 #ifdef _WIN32
     if (result == SOCKET_ERROR)
     {
@@ -1341,6 +1341,22 @@
       }
 #endif // _WIN32
     }
+
+    struct ip_mreq mreq;
+    memset(&mreq, 0, sizeof(struct ip_mreq));
+    //unsigned long addr = inet_addr(hostname);
+
+    inet_aton(hostname, &mreq.imr_multiaddr);
+    //memcpy(&mreq.imr_multiaddr.s_addr, hp->h_addr, hp->h_length);
+    mreq.imr_interface.s_addr=INADDR_ANY;
+
+    result = setsockopt(output, IPPROTO_IP, IP_ADD_MEMBERSHIP, &mreq, sizeof(mreq));
+    if (result < 0)
+    {
+      fprint_err("### Unable to set join multicast group %s: %s\n",
+                 hostname,strerror(errno));
+      return -1;
+    }
   }

   result = connect(output,(struct sockaddr*)&ipaddr,sizeof(ipaddr));
@@ -1358,7 +1374,7 @@
   {
     fprint_err("### Unable to connect to host %s: %s\n",
                hostname,strerror(errno));
-    return -1;
+    //return -1;
   }
 #endif // _WIN32
   return output;
diff -r 33deaa931635 pes.c
--- a/pes.c     Thu Sep 30 14:30:34 2010 +0100
+++ b/pes.c     Thu Jul 21 22:11:52 2011 +0300
@@ -1865,7 +1865,7 @@
   else
   {
     PS_reader_p  ps;
-    err = build_PS_reader(input,!give_info,&ps);
+    err = build_PS_reader(input,!give_info,&ps,1);
     if (err)
     {
       print_err("### Error building PS specific reader\n");
diff -r 33deaa931635 ps.c
--- a/ps.c      Thu Sep 30 14:30:34 2010 +0100
+++ b/ps.c      Thu Jul 21 22:11:52 2011 +0300
@@ -133,7 +133,8 @@
  */
 extern int build_PS_reader(int           input,
                            int           quiet,
-                           PS_reader_p  *ps)
+                           PS_reader_p  *ps,
+                           int seekable)
 {
   int  err;
   PS_reader_p new = malloc(SIZEOF_PS_READER);
@@ -169,7 +170,7 @@
   }

   // Seeking won't work on standard input, so don't even try
-  if (input != STDIN_FILENO)
+  if (input != STDIN_FILENO && seekable)
   {
     // But we don't *really* want to have read its start yet
     err = seek_using_PS_reader(new,new->start);
@@ -223,7 +224,7 @@
                         int           quiet,
                         PS_reader_p  *ps)
 {
-  int  f;
+  int  f,seekable=1;

   if (name == NULL)
     f = STDIN_FILENO;
@@ -231,8 +232,10 @@
   {
     f = open_binary_file(name,FALSE);
     if (f == -1) return 1;
+    if(strstr(name, "/dev/video")==name)
+       seekable=0;
   }
-  return build_PS_reader(f,quiet,ps);
+  return build_PS_reader(f,quiet,ps,seekable);
 }
 ^L
 /*
diff -r 33deaa931635 ps2ts.c
--- a/ps2ts.c   Thu Sep 30 14:30:34 2010 +0100
+++ b/ps2ts.c   Thu Jul 21 22:11:52 2011 +0300
@@ -484,7 +484,7 @@
   if (use_stdout)
     err = tswrite_open(TS_W_STDOUT,NULL,NULL,0,quiet,&output);
   else if (use_tcpip)
-    err = tswrite_open(TS_W_TCP,output_name,NULL,port,quiet,&output);
+    err = tswrite_open(TS_W_UDP,output_name,NULL,port,quiet,&output);
   else
     err = tswrite_open(TS_W_FILE,output_name,NULL,0,quiet,&output);
   if (err)
diff -r 33deaa931635 ps_fns.h
--- a/ps_fns.h  Thu Sep 30 14:30:34 2010 +0100
+++ b/ps_fns.h  Thu Jul 21 22:11:52 2011 +0300
@@ -50,7 +50,8 @@
  */
 extern int build_PS_reader(int           input,
                            int           quiet,
-                           PS_reader_p  *ps);
+                           PS_reader_p  *ps,
+                           int seekable);
 /*
  * Tidy up the PS read-ahead context after we've finished with it.
  *
diff -r 33deaa931635 tsplay.c
--- a/tsplay.c  Thu Sep 30 14:30:34 2010 +0100
+++ b/tsplay.c  Thu Jul 21 22:11:52 2011 +0300
@@ -739,7 +739,7 @@
       fprint_err("### tsplay: Unable to open input file %s\n",input_name);
       return 1;
     }
-
+#if 0
     err = determine_if_TS_file(input,&is_TS);
     if (err)
     {
@@ -747,12 +747,15 @@
       (void) close_file(input);
       return 1;
     }
+#else
+    is_TS = FALSE;                       // an assertion
+#endif
   }
   else
   {
     input_name = "<stdin>";
     input = STDIN_FILENO;
-    is_TS = TRUE;                       // an assertion
+    is_TS = FALSE;                       // an assertion
   }
   if (!quiet)
     fprint_msg("Reading from  %s%s\n",input_name,(loop?" (and looping)":""));
diff -r 33deaa931635 tsplay_innards.c
--- a/tsplay_innards.c  Thu Sep 30 14:30:34 2010 +0100
+++ b/tsplay_innards.c  Thu Jul 21 22:11:52 2011 +0300
@@ -736,7 +736,7 @@
   int  is_h264;
   PS_reader_p   ps;

-  err = build_PS_reader(input,quiet,&ps);
+  err = build_PS_reader(input,quiet,&ps,0);
   if (err)
   {
     print_err("### Error building PS reader for input\n");
@@ -761,7 +761,7 @@
   }

   err = ps_to_ts(ps,output,pad_start,program_repeat,
-                 is_h264,input_is_dvd,
+                 is_h264?VIDEO_H264:VIDEO_H262, input_is_dvd,
                  video_stream,audio_stream,want_ac3_audio,
                  want_dolby_as_dvb,pmt_pid,pcr_pid,
                  video_pid,keep_audio,audio_pid,max,verbose,quiet);
diff -r 33deaa931635 tswrite.c
--- a/tswrite.c Thu Sep 30 14:30:34 2010 +0100
+++ b/tswrite.c Thu Jul 21 22:11:52 2011 +0300
@@ -2638,8 +2638,15 @@
       if (err) return err;  // important, because it might be 0, 1 or EOF
       break;
     case TS_W_UDP:
-      err = write_socket_data(tswriter->where.socket,packet,TS_PACKET_SIZE);
-      if (err) return 1;
+       memcpy(tswriter->buffer_writer + TS_PACKET_SIZE*tswriter->buffer_fullness,
+                       packet, TS_PACKET_SIZE);
+       tswriter->buffer_fullness++;
+               if(tswriter->buffer_fullness >= 7) {
+            err = write_socket_data(tswriter->where.socket,tswriter->buffer_writer,
+                       tswriter->buffer_fullness*TS_PACKET_SIZE);
+            tswriter->buffer_fullness=0;
+            if (err) return 1;
+       }
       break;
     default:
       fprint_err("### Unexpected writer type %d to tswrite_write()\n",
diff -r 33deaa931635 tswrite_defns.h
--- a/tswrite_defns.h   Thu Sep 30 14:30:34 2010 +0100
+++ b/tswrite_defns.h   Thu Jul 21 22:11:52 2011 +0300
@@ -271,6 +271,8 @@
   // useful for debugging other applications
   int    drop_packets;  // 0 to keep all packets, otherwise keep <n> packets
   int    drop_number;   // and then drop this many
+  uint8_t buffer_writer[TS_PACKET_SIZE*7];
+  int buffer_fullness;
 };
 typedef struct TS_writer *TS_writer_p;
 #define SIZEOF_TS_WRITER sizeof(struct TS_writer)
 